@@ -167,12 +167,15 @@ class EcoVacsIOTMQ(ClientMQTT):
         params = {}
         params.update(args)
 
+        _LOGGER.debug("calling IOT api with {}".format(args))
+
         headers = {'User-Agent': 'Dalvik/2.1.0 (Linux; U; Android 5.1.1; A5010 Build/LMY48Z)',}
         url = (self.portal_url_format + "/iot/devmanager.do?mid=" + params['toType'] + "&did=" + params['toId'] + "&td=" + params['td'] + "&u=" + params['auth']['userid'] + "&cv=1.67.3&t=a&av=1.3.1").format(continent=self.continent)
         
         try:  
             with requests.post(url, headers=headers, json=params, timeout=20, verify=verify_ssl) as response:
                 data = response.json()
+                _LOGGER.debug("got {}".format(data))
                 if response.status_code != 200:
                     _LOGGER.warning("Error calling API " + str(url))
 
